@@ -4,11 +4,12 @@ uploadPattern =  function(x, horizontal=FALSE, ...) {
 	if( class(x) != "accrued" )  stop("ERROR: argument is not an object of the 'data.accrued' class.")
 
 	accrued_data = x		
+			
 		
 	MAX_LAGS = ncol(accrued_data[["data"]]) - 1	
 	NCOL = ncol(accrued_data[["data"]])
 	NROW = nrow(accrued_data[["data"]])
-	STACKED = stackedUploadData( accrued_data )
+	STACKED = as.data.frame(stackedUploadData( accrued_data ))
 
 	LAGS = 0:MAX_LAGS
 
@@ -25,6 +26,7 @@ uploadPattern =  function(x, horizontal=FALSE, ...) {
 
 	## Specifications if a diagonal plot is desired. 
 	## This must come before Y_MIN and Y_MAX are specified since Y is reassigned here.
+	ASPECT_RATIO = 1
 	if( !horizontal ){
 		Y = STACKED[, "EncounterDate"]
 		ASPECT_RATIO = 1
@@ -33,28 +35,28 @@ uploadPattern =  function(x, horizontal=FALSE, ...) {
 	}
 
 	## Plot limits.
-	X_MIN = min(X, na.rm=T);
-	X_MAX = max(X, na.rm=T);
-	Y_MIN = min(Y, na.rm=T); 
-	Y_MAX = max(Y, na.rm=T);
+	X_MIN = min(X, na.rm=T)
+	X_MAX = max(X, na.rm=T)
+	Y_MIN = min(Y, na.rm=T) 
+	Y_MAX = max(Y, na.rm=T)
 
 	if( X_MIN == X_MAX ) X_MAX = X_MIN + 1
 	if( Y_MIN == Y_MAX ) Y_MAX = Y_MIN + 1
 
 	## Aspect Ratio is optimized for around 100-200 upload dates and 20 lags.
-	ASPECT_RATIO = 0.125
-	ASPECT_RATIO = (Y_MAX-Y_MIN)/(X_MAX-X_MIN) + 0.025
+	if( horizontal ) { ASPECT_RATIO = (Y_MAX-Y_MIN)/(X_MAX-X_MIN) + 0.025 }
 	X_LABEL = Y_LABEL = ""
 	BOTTOM_MARGIN = LEFT_MARGIN = 0.5
 	TOP_MARGIN = RIGHT_MARGIN = 0.25
 
 	## If a start date is provided, make margins large enough to accommodate the date labels.
-	if( accrued_data[["start"]][[1]] )  BOTTOM_MARGIN = LEFT_MARGIN = 1
+	START_DATE = accrued_data[["start"]][[1]]
+	if( START_DATE != 1  )  BOTTOM_MARGIN = LEFT_MARGIN = 1
 	
  	par(  mai=c( BOTTOM_MARGIN, LEFT_MARGIN, TOP_MARGIN, RIGHT_MARGIN )  )
  	plot( X, Y, 
- 	      xlim=c(X_MIN,X_MAX), 
- 	      ylim=c(Y_MIN,Y_MAX+1), 
+ 	      xlim=c(X_MIN, X_MAX), 
+ 	      ylim=c(Y_MIN, Y_MAX+1), 
  	      xlab=X_LABEL, 
  	      ylab=Y_LABEL,
 	      main="", type='n', 
@@ -68,26 +70,53 @@ uploadPattern =  function(x, horizontal=FALSE, ...) {
 			      col=rgb(1, 0.75, 0.5), border=FALSE ) 
 	}
 	else {
-		polygon(  c( X_MIN-HORIZONTAL_PADDING  , X_MAX+HORIZONTAL_PADDING	  , X_MAX+HORIZONTAL_PADDING, X_MIN-HORIZONTAL_PADDING ), 	
-			      c( Y_MIN-LOWER_VERTICAL_SHIFT, Y_MIN-LOWER_VERTICAL_SHIFT, Y_MAX+1       , Y_MAX+1 ), 
+		polygon(  c( X_MIN-HORIZONTAL_PADDING  , X_MAX+HORIZONTAL_PADDING  , X_MAX+HORIZONTAL_PADDING, X_MIN-HORIZONTAL_PADDING ), 	
+			      c( Y_MIN-LOWER_VERTICAL_SHIFT, Y_MIN-LOWER_VERTICAL_SHIFT, Y_MAX+1                 , Y_MAX+1 ), 
 			      col=rgb(1, 0.75, 0.5), border=FALSE ) 
 	}
 
 
-	## Draw the dark blue box at a (i,j) if an upload on day i containing data from day j was uploaded.
+	####################################################################
+	## Draw the dark blue box at a (i,j) if an upload on day i 
+	## containing data from day j was uploaded, with positive counts.
+	## Draw the gray box at a (i,j) if an upload on day i containing 
+	## data from day j was uploaded, with zero counts.
+	## Otherwise no box is drawn.
+	####################################################################
 
 	## This is the vector of numbers added.
 	NUM_ADDED = STACKED[ , "NumberAdded"]
-	## This is an indicator vector of the non-missing number added.
-	NON_NA_NUM_ADDED = !is.na(NUM_ADDED)
-	## This reassignes all missing values to zero. These two vectors will be used in blue rectangles below.
-	NUM_ADDED[ is.na(NUM_ADDED) ] = is.na(NUM_ADDED[is.na(NUM_ADDED)]) - 1 
-	SELECTION_VECTOR = NUM_ADDED>0 & NON_NA_NUM_ADDED
-	for( R in 1:length(SELECTION_VECTOR))
-		if( SELECTION_VECTOR[R] ){ polygon( c( X[R], X[R]+1, X[R]+1, X[R]   ), 
+	NOT_NA_AND_POS  = (NUM_ADDED > 0)  & !is.na(NUM_ADDED)
+	NOT_NA_AND_ZERO = (NUM_ADDED == 0) & !is.na(NUM_ADDED)
+
+	NO_PRIOR_DATA = rep(T, times=length(NUM_ADDED)) 
+	for( R in 1:length(NO_PRIOR_DATA) ) {
+		lag = STACKED[R, "Lag"]
+		encounterDate = STACKED[R, "EncounterDate"]
+		if( lag > 0 ){ 
+			temp = STACKED[ STACKED$EncounterDate==encounterDate & STACKED$Lag<lag & !is.na(STACKED$Counts),"Counts"] 
+			if( length(temp) > 0 )  
+				if( sum(temp > 0) > 0) NO_PRIOR_DATA[R] = F
+		}
+		
+	}
+		
+	## Positive counts are set to 2, "0" counts, or <0 counts remain at 1.
+	## But, if counts have already been received for that encounter date and lag combination,
+	SELECTION_VECTOR = rep(0, times=length(NUM_ADDED)) 
+	for( R in 1:length(SELECTION_VECTOR) ) {
+		if( NOT_NA_AND_POS[R] ) SELECTION_VECTOR[R] = 2
+		if( NOT_NA_AND_ZERO[R]& NO_PRIOR_DATA[R] ) SELECTION_VECTOR[R] = 1
+	}
+
+	for( R in 1:length(SELECTION_VECTOR)) { 
+		if( SELECTION_VECTOR[R] == 2 ) polygon( c( X[R], X[R]+1, X[R]+1, X[R]   ), 
                                             c( Y[R], Y[R]  , Y[R]+1, Y[R]+1 ), 
                                             col="darkblue", border=FALSE ) 
-	} 
+		if( SELECTION_VECTOR[R] == 1 ) polygon( c( X[R], X[R]+1, X[R]+1, X[R]   ), 
+                                            c( Y[R], Y[R]  , Y[R]+1, Y[R]+1 ), 
+                                            col="gray", border=FALSE ) 
+ 	}
 			
 	## Add vertical white lines to make the boxes more distinct.
 	if( horizontal ) abline( v=(X_MIN-HORIZONTAL_PADDING):(X_MAX+MAX_LAGS), cex=0.15, col="white" ) 	
@@ -116,11 +145,11 @@ uploadPattern =  function(x, horizontal=FALSE, ...) {
 	Y_CEX_AXIS = 0.8
 	Y_FONT_AXIS = 1
 
+
 	## If a start date is specified, set the x-labels which are the same regardless of the value of "horizontal".
-	if( accrued_data[["start"]][[1]] ) {
-		# x-axis labels need to be dates because the argument is TRUE.
+	if( START_DATE != 1 ) {
+		# x-axis labels need to be dates.
 		# x-axis labels are the same, regardless of whether "horizontal" is TRUE or FALSE.
-		START_DATE = accrued_data[["start"]][[2]]
 		X_LABELS = as.Date(START_DATE + X_TICK_PLACES, origin=as.Date("1970-01-01")) 
 		X_LABEL_ORIENTATION = 2
 	} 
